==> deepin-calculator_5.7.0.15.orig.tar.xz: deepin-calculator-5.7.0.15/translations/deepin-calculator_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Error de expresión</translation>
    </message>
</context>
<context>
    <name>IconButton</name>
    <message>
        <source>Clear all memory</source>
        <translation>Borrar toda la memoria</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Limpiar historial</translation>
    </message>
</context>
<context>
    <name>InputEdit</name>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Seleccionar todo</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Deshacer</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Rehacer</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Calculator</source>
        <translation>Calculadora</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>Estándar</translation>
    </message>
    <message>
        <source>Scientific</source>
        <translation>Científica</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <source>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</source>
        <translation>La calculadora es una calculadora de escritorio fácil de usar, que soporta los modos estándar, científico y programador.</translation>
    </message>
    <message>
        <source>Programmer</source>
        <translation>Programador</translation>
    </message>
</context>
<context>
    <name>MemoryButton</name>
    <message>
        <source>Clear memory item</source>
        <translation>Borrar el elemento de memoria</translation>
    </message>
    <message>
        <source>Clear all memory</source>
        <translation>Borrar toda la memoria</translation>
    </message>
    <message>
        <source>Memory recall</source>
        <translation>Recuperar memoria</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Sumar elemento a la memoria</translation>
    </message>
    <message>
        <source>Memory add</source>
        <translation>Sumar a la memoria </translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Restar elemento a la memoria</translation>
    </message>
    <message>
        <source>Memory subtract</source>
        <translation>Restar a la memoria</translation>
    </message>
    <message>
        <source>Memory store</source>
        <translation>Guardar en memoria</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memoria</translation>
    </message>
</context>
<context>
    <name>MemoryItemWidget</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Clear memory item</source>
        <translation>Borrar el elemento de la memoria</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Sumar elemento a la memoria</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Restar elemento a la memoria</translation>
    </message>
</context>
<context>
    <name>MemoryWidget</name>
    <message>
        <source>Nothing saved in memory</source>
        <translation>No hay nada guardado en la memoria</translation>
    </message>
</context>
<context>
    <name>ProExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Error de expresión</translation>
    </message>
</context>
<context>
    <name>ProListView</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
</context>
<context>
    <name>ProgramModule</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Desplazamiento aritmético</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Desplazamiento lógico</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Desplazamiento circular</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Rotación a través del acarreo</translation>
    </message>
</context>
<context>
    <name>ProgrammerItemWidget</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Desplazamiento aritmético</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Desplazamiento lógico</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Desplazamiento circular</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Rotación a través del acarreo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Calculator</source>
        <translation>Calculadora</translation>
    </message>
</context>
<context>
    <name>SciExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Error de expresión</translation>
    </message>
</context>
<context>
    <name>SciHistoryWidget</name>
    <message>
        <source>History</source>
        <translation>Historial</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memoria</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression error</source>
        <translation>Error de expresión</translation>
    </message>
</context>
<context>
    <name>SimpleListModel</name>
    <message>
        <source>No history</source>
        <translation>No hay historial</translation>
    </message>
</context>
<context>
    <name>SimpleListView</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
</context>
</TS>

==> deepin-calculator_5.7.20.orig.tar.xz: deepin-calculator-5.7.20/translations/deepin-calculator_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Error de expresión</translation>
    </message>
</context>
<context>
    <name>IconButton</name>
    <message>
        <source>Clear all memory</source>
        <translation>Borrar toda la memoria</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Limpiar historial</translation>
    </message>
</context>
<context>
    <name>InputEdit</name>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Seleccionar todo</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Deshacer</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Rehacer</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Calculator</source>
        <translation>Calculadora</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>Estándar</translation>
    </message>
    <message>
        <source>Scientific</source>
        <translation>Científica</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <source>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</source>
        <translation>La calculadora es una aplicación de escritorio, fácil de usar que soporta los modos estándar, científico y programador.</translation>
    </message>
    <message>
        <source>Programmer</source>
        <translation>Programador</translation>
    </message>
</context>
<context>
    <name>MemoryButton</name>
    <message>
        <source>Clear memory item</source>
        <translation>Borrar el elemento de memoria</translation>
    </message>
    <message>
        <source>Clear all memory</source>
        <translation>Borrar toda la memoria</translation>
    </message>
    <message>
        <source>Memory recall</source>
        <translation>Recuperar memoria</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Sumar elemento a la memoria</translation>
    </message>
    <message>
        <source>Memory add</source>
        <translation>Sumar a la memoria </translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Restar elemento a la memoria</translation>
    </message>
    <message>
        <source>Memory subtract</source>
        <translation>Restar a la memoria</translation>
    </message>
    <message>
        <source>Memory store</source>
        <translation>Guardar en memoria</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memoria</translation>
    </message>
</context>
<context>
    <name>MemoryItemWidget</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Clear memory item</source>
        <translation>Borrar el elemento de la memoria</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Sumar elemento a la memoria</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Restar elemento a la memoria</translation>
    </message>
</context>
<context>
    <name>MemoryWidget</name>
    <message>
        <source>Nothing saved in memory</source>
        <translation>No hay nada guardado en la memoria</translation>
    </message>
</context>
<context>
    <name>ProExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Error de expresión</translation>
    </message>
</context>
<context>
    <name>ProListView</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
</context>
<context>
    <name>ProgramModule</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Desplazamiento aritmético</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Desplazamiento lógico</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Desplazamiento circular</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Rotación a través del acarreo</translation>
    </message>
</context>
<context>
    <name>ProgrammerItemWidget</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Desplazamiento aritmético</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Desplazamiento lógico</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Desplazamiento circular</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Rotación a través del acarreo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Calculator</source>
        <translation>Calculadora</translation>
    </message>
</context>
<context>
    <name>SciExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Error de expresión</translation>
    </message>
</context>
<context>
    <name>SciHistoryWidget</name>
    <message>
        <source>History</source>
        <translation>Historial</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memoria</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression error</source>
        <translation>Error de expresión</translation>
    </message>
</context>
<context>
    <name>SimpleListModel</name>
    <message>
        <source>No history</source>
        <translation>No hay historial</translation>
    </message>
</context>
<context>
    <name>SimpleListView</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
</context>
</TS>
